==> nhc98_1.16.orig.tar.gz: nhc98-1.16/src/prelude/Binary/IsEOFBin.p.c <==
#include "newmacros.h"
#include "runtime.h"

#define FN_NHC_46Binary_46hs_95isEOFBin_35	((void*)startLabel+8)
#define CT_v180	((void*)startLabel+32)
#define F0_NHC_46Binary_46hs_95isEOFBin_35	((void*)startLabel+40)
#define FN_NHC_46Binary_46hs_95isEOFBin	((void*)startLabel+68)
#define CT_v184	((void*)startLabel+120)
#define CF_NHC_46Binary_46hs_95isEOFBin	((void*)startLabel+128)
#define CT_v188	((void*)startLabel+220)
#define PP_NHC_46Binary_46hs_95isEOFBin	((void*)startLabel+252)
#define PC_NHC_46Binary_46hs_95isEOFBin	((void*)startLabel+252)
#define ST_v182	((void*)startLabel+252)
#define PP_NHC_46Binary_46hs_95isEOFBin_35	((void*)startLabel+275)
#define PC_NHC_46Binary_46hs_95isEOFBin_35	((void*)startLabel+275)
#define ST_v179	((void*)startLabel+275)
#define ST_v186	((void*)startLabel+300)
#define PS_v183	((void*)startLabel+320)
#define PS_v181	((void*)startLabel+332)
#define PS_v187	((void*)startLabel+344)
#define PS_v185	((void*)startLabel+356)
#define PS_v178	((void*)startLabel+368)
void FR_NHC_46Binary_46hs_95isEOFBin_35(void);
extern Node FN_NHC_46Internal_46_95mkIOok1[];
extern Node PM_NHC_46Binary[];
extern Node PC_NHC_46Internal_46_95mkIOok1[];
extern Node PM_NHC_46Binary[];
extern Node PM_NHC_46Binary[];
extern Node PM_NHC_46Binary[];
extern Node PM_NHC_46Binary[];

static Node startLabel[] = {
  bytes2word(1,0,0,1)
, useLabel(CT_v180)
,	/* FN_NHC_46Binary_46hs_95isEOFBin_35: (byte 0) */
  bytes2word(PUSH_ARG_I1,EVAL,POP_I1,PRIMITIVE)
, useLabel(FR_NHC_46Binary_46hs_95isEOFBin_35)
, bytes2word(RETURN_EVAL,ENDCODE,0,0)
, bytes2word(0,0,0,0)
, 90022
, useLabel(ST_v179)
,	/* CT_v180: (byte 0) */
  HW(0,1)
, 0
,	/* F0_NHC_46Binary_46hs_95isEOFBin_35: (byte 0) */
  CAPTAG(useLabel(FN_NHC_46Binary_46hs_95isEOFBin_35),1)
, useLabel(PS_v178)
, 0
, 0
, 0
, bytes2word(0,0,0,0)
, useLabel(CT_v184)
,	/* FN_NHC_46Binary_46hs_95isEOFBin: (byte 0) */
  bytes2word(NEEDHEAP_I32,PUSH_HEAP,HEAP_CVAL_P1,7)
, bytes2word(HEAP_CVAL_N1,7,HEAP_CREATE,HEAP_SPACE)
, bytes2word(HEAP_SPACE,HEAP_CVAL_P1,8,RETURN_EVAL)
, bytes2word(ENDCODE,0,0,0)
, bytes2word(0,0,0,0)
, 0
, useLabel(PS_v183)
, 0
, 0
, 0
, 0
, 90022
, useLabel(ST_v182)
,	/* CT_v184: (byte 0) */
  HW(2,0)
, 0
,	/* CF_NHC_46Binary_46hs_95isEOFBin: (byte 0) */
  VAPTAG(useLabel(FN_NHC_46Binary_46hs_95isEOFBin))
, useLabel(PS_v181)
, 0
, 0
, 0
, VAPTAG(useLabel(FN_NHC_46Internal_46_95mkIOok1))
, useLabel(F0_NHC_46Binary_46hs_95isEOFBin_35)
, bytes2word(1,0,0,1)
, useLabel(CT_v188)
,};
Node FN_NHC_46Binary_46isEOFBin[] = {
  bytes2word(NEEDHEAP_I32,PUSH_ARG_I1,PUSH_HEAP,HEAP_CVAL_P1)
, bytes2word(7,HEAP_CVAL_N1,7,HEAP_CREATE)
, bytes2word(HEAP_SPACE,HEAP_SPACE,ZAP_ARG_I1,EVAL)
, bytes2word(NEEDHEAP_I32,APPLY,1,RETURN_EVAL)
, bytes2word(ENDCODE,0,0,0)
, bytes2word(0,0,0,0)
, 0
, useLabel(PS_v187)
, 0
, 0
, 0
, 0
, 120001
, useLabel(ST_v186)
,	/* CT_v188: (byte 0) */
  HW(1,1)
, 0
,};
Node F0_NHC_46Binary_46isEOFBin[] = {
  CAPTAG(useLabel(FN_NHC_46Binary_46isEOFBin),1)
, useLabel(PS_v185)
, 0
, 0
, 0
, VAPTAG(useLabel(FN_NHC_46Binary_46hs_95isEOFBin))
,	/* PP_NHC_46Binary_46hs_95isEOFBin: (byte 0) */
 	/* PC_NHC_46Binary_46hs_95isEOFBin: (byte 0) */
 	/* ST_v182: (byte 0) */
  bytes2word(78,72,67,46)
, bytes2word(66,105,110,97)
, bytes2word(114,121,46,104)
, bytes2word(115,95,105,115)
, bytes2word(69,79,70,66)
,	/* PP_NHC_46Binary_46hs_95isEOFBin_35: (byte 3) */
 	/* PC_NHC_46Binary_46hs_95isEOFBin_35: (byte 3) */
 	/* ST_v179: (byte 3) */
  bytes2word(105,110,0,78)
, bytes2word(72,67,46,66)
, bytes2word(105,110,97,114)
, bytes2word(121,46,104,115)
, bytes2word(95,105,115,69)
, bytes2word(79,70,66,105)
, bytes2word(110,35,0,0)
,};
Node PP_NHC_46Binary_46isEOFBin[] = {
 };
Node PC_NHC_46Binary_46isEOFBin[] = {
 	/* ST_v186: (byte 0) */
  bytes2word(78,72,67,46)
, bytes2word(66,105,110,97)
, bytes2word(114,121,46,105)
, bytes2word(115,69,79,70)
, bytes2word(66,105,110,0)
,	/* PS_v183: (byte 0) */
  useLabel(PM_NHC_46Binary)
, useLabel(PP_NHC_46Binary_46hs_95isEOFBin)
, useLabel(PC_NHC_46Internal_46_95mkIOok1)
,	/* PS_v181: (byte 0) */
  useLabel(PM_NHC_46Binary)
, useLabel(PP_NHC_46Binary_46hs_95isEOFBin)
, useLabel(PC_NHC_46Binary_46hs_95isEOFBin)
,	/* PS_v187: (byte 0) */
  useLabel(PM_NHC_46Binary)
, useLabel(PP_NHC_46Binary_46isEOFBin)
, useLabel(PC_NHC_46Binary_46hs_95isEOFBin)
,	/* PS_v185: (byte 0) */
  useLabel(PM_NHC_46Binary)
, useLabel(PP_NHC_46Binary_46isEOFBin)
, useLabel(PC_NHC_46Binary_46isEOFBin)
,	/* PS_v178: (byte 0) */
  useLabel(PM_NHC_46Binary)
, useLabel(PP_NHC_46Binary_46hs_95isEOFBin_35)
, useLabel(PC_NHC_46Binary_46hs_95isEOFBin_35)
,};

#include <haskell2c.h>
#include <HsFFI.h>

/* foreign import ccall "hs_isEOFBin" NHC.Binary.hs_isEOFBin# 1 :: FFI.ForeignObj -> Prelude.Bool */
extern HsBool hs_isEOFBin(void*);
#ifdef PROFILE
static SInfo pf_hs_isEOFBin = {"NHC.Binary","NHC.Binary.hs_isEOFBin#","Prelude.Bool"};
#endif
C_HEADER(FR_NHC_46Binary_46hs_95isEOFBin_35) {
  NodePtr nodeptr;
  HsBool result;
  void* arg1;
  nodeptr = C_GETARG1(1);
  IND_REMOVE(nodeptr);
  arg1 = (void*)derefForeignObj((ForeignObj*)GET_INT_VALUE(nodeptr));

  result = hs_isEOFBin(arg1);

  nodeptr = nhc_mkBool(result);
  INIT_PROFINFO(nodeptr,&pf_hs_isEOFBin);
  C_RETURN(nodeptr);
}

==> nhc98_1.18.orig.tar.gz: nhc98-1.18/src/prelude/Binary/IsEOFBin.p.c <==
#include "newmacros.h"
#include "runtime.h"

#define FN_NHC_46Binary_46hs_95isEOFBin_35	((void*)startLabel+8)
#define CT_v184	((void*)startLabel+32)
#define F0_NHC_46Binary_46hs_95isEOFBin_35	((void*)startLabel+40)
#define FN_NHC_46Binary_46hs_95isEOFBin	((void*)startLabel+68)
#define CT_v188	((void*)startLabel+120)
#define CF_NHC_46Binary_46hs_95isEOFBin	((void*)startLabel+128)
#define CT_v192	((void*)startLabel+220)
#define PP_NHC_46Binary_46hs_95isEOFBin	((void*)startLabel+252)
#define PC_NHC_46Binary_46hs_95isEOFBin	((void*)startLabel+252)
#define ST_v186	((void*)startLabel+252)
#define PP_NHC_46Binary_46hs_95isEOFBin_35	((void*)startLabel+275)
#define PC_NHC_46Binary_46hs_95isEOFBin_35	((void*)startLabel+275)
#define ST_v183	((void*)startLabel+275)
#define ST_v190	((void*)startLabel+300)
#define PS_v187	((void*)startLabel+320)
#define PS_v185	((void*)startLabel+332)
#define PS_v191	((void*)startLabel+344)
#define PS_v189	((void*)startLabel+356)
#define PS_v182	((void*)startLabel+368)
void FR_NHC_46Binary_46hs_95isEOFBin_35(void);
extern Node FN_NHC_46Internal_46_95mkIOok1[];
extern Node PM_NHC_46Binary[];
extern Node PC_NHC_46Internal_46_95mkIOok1[];

static Node startLabel[] = {
  bytes2word(1,0,0,1)
, useLabel(CT_v184)
,	/* FN_NHC_46Binary_46hs_95isEOFBin_35: (byte 0) */
  bytes2word(PUSH_ARG_I1,EVAL,POP_I1,PRIMITIVE)
, useLabel(FR_NHC_46Binary_46hs_95isEOFBin_35)
, bytes2word(RETURN_EVAL,ENDCODE,0,0)
, bytes2word(0,0,0,0)
, 90001
, useLabel(ST_v183)
,	/* CT_v184: (byte 0) */
  HW(0,1)
, 0
,	/* F0_NHC_46Binary_46hs_95isEOFBin_35: (byte 0) */
  CAPTAG(useLabel(FN_NHC_46Binary_46hs_95isEOFBin_35),1)
, useLabel(PS_v182)
, 0
, 0
, 0
, bytes2word(0,0,0,0)
, useLabel(CT_v188)
,	/* FN_NHC_46Binary_46hs_95isEOFBin: (byte 0) */
  bytes2word(NEEDHEAP_I32,PUSH_HEAP,HEAP_CVAL_P1,7)
, bytes2word(HEAP_CVAL_N1,7,HEAP_CREATE,HEAP_SPACE)
, bytes2word(HEAP_SPACE,HEAP_CVAL_P1,8,RETURN_EVAL)
, bytes2word(ENDCODE,0,0,0)
, bytes2word(0,0,0,0)
, 0
, useLabel(PS_v187)
, 0
, 0
, 0
, 0
, 90001
, useLabel(ST_v186)
,	/* CT_v188: (byte 0) */
  HW(2,0)
, 0
,	/* CF_NHC_46Binary_46hs_95isEOFBin: (byte 0) */
  VAPTAG(useLabel(FN_NHC_46Binary_46hs_95isEOFBin))
, useLabel(PS_v185)
, 0
, 0
, 0
, VAPTAG(useLabel(FN_NHC_46Internal_46_95mkIOok1))
, useLabel(F0_NHC_46Binary_46hs_95isEOFBin_35)
, bytes2word(1,0,0,1)
, useLabel(CT_v192)
,};
Node FN_NHC_46Binary_46isEOFBin[] = {
  bytes2word(NEEDHEAP_I32,PUSH_ARG_I1,PUSH_HEAP,HEAP_CVAL_P1)
, bytes2word(7,HEAP_CVAL_N1,7,HEAP_CREATE)
, bytes2word(HEAP_SPACE,HEAP_SPACE,ZAP_ARG_I1,EVAL)
, bytes2word(NEEDHEAP_I32,APPLY,1,RETURN_EVAL)
, bytes2word(ENDCODE,0,0,0)
, bytes2word(0,0,0,0)
, 0
, useLabel(PS_v191)
, 0
, 0
, 0
, 0
, 120001
, useLabel(ST_v190)
,	/* CT_v192: (byte 0) */
  HW(1,1)
, 0
,};
Node F0_NHC_46Binary_46isEOFBin[] = {
  CAPTAG(useLabel(FN_NHC_46Binary_46isEOFBin),1)
, useLabel(PS_v189)
, 0
, 0
, 0
, VAPTAG(useLabel(FN_NHC_46Binary_46hs_95isEOFBin))
,	/* PP_NHC_46Binary_46hs_95isEOFBin: (byte 0) */
 	/* PC_NHC_46Binary_46hs_95isEOFBin: (byte 0) */
 	/* ST_v186: (byte 0) */
  bytes2word(78,72,67,46)
, bytes2word(66,105,110,97)
, bytes2word(114,121,46,104)
, bytes2word(115,95,105,115)
, bytes2word(69,79,70,66)
,	/* PP_NHC_46Binary_46hs_95isEOFBin_35: (byte 3) */
 	/* PC_NHC_46Binary_46hs_95isEOFBin_35: (byte 3) */
 	/* ST_v183: (byte 3) */
  bytes2word(105,110,0,78)
, bytes2word(72,67,46,66)
, bytes2word(105,110,97,114)
, bytes2word(121,46,104,115)
, bytes2word(95,105,115,69)
, bytes2word(79,70,66,105)
, bytes2word(110,35,0,0)
,};
Node PP_NHC_46Binary_46isEOFBin[] = {
 };
Node PC_NHC_46Binary_46isEOFBin[] = {
 	/* ST_v190: (byte 0) */
  bytes2word(78,72,67,46)
, bytes2word(66,105,110,97)
, bytes2word(114,121,46,105)
, bytes2word(115,69,79,70)
, bytes2word(66,105,110,0)
,	/* PS_v187: (byte 0) */
  useLabel(PM_NHC_46Binary)
, useLabel(PP_NHC_46Binary_46hs_95isEOFBin)
, useLabel(PC_NHC_46Internal_46_95mkIOok1)
,	/* PS_v185: (byte 0) */
  useLabel(PM_NHC_46Binary)
, useLabel(PP_NHC_46Binary_46hs_95isEOFBin)
, useLabel(PC_NHC_46Binary_46hs_95isEOFBin)
,	/* PS_v191: (byte 0) */
  useLabel(PM_NHC_46Binary)
, useLabel(PP_NHC_46Binary_46isEOFBin)
, useLabel(PC_NHC_46Binary_46hs_95isEOFBin)
,	/* PS_v189: (byte 0) */
  useLabel(PM_NHC_46Binary)
, useLabel(PP_NHC_46Binary_46isEOFBin)
, useLabel(PC_NHC_46Binary_46isEOFBin)
,	/* PS_v182: (byte 0) */
  useLabel(PM_NHC_46Binary)
, useLabel(PP_NHC_46Binary_46hs_95isEOFBin_35)
, useLabel(PC_NHC_46Binary_46hs_95isEOFBin_35)
,};

#include <haskell2c.h>
#include <HsFFI.h>

/* foreign import ccall "hs_isEOFBin" NHC.Binary.hs_isEOFBin# 1 :: FFI.ForeignObj -> Prelude.Bool */
extern HsBool hs_isEOFBin(void*);
#ifdef PROFILE
static SInfo pf_NHC_46Binary_46hs_95isEOFBin_35 = {"NHC.Binary","NHC.Binary.hs_isEOFBin#","Prelude.Bool"};
#endif
C_HEADER(FR_NHC_46Binary_46hs_95isEOFBin_35) {
  NodePtr nodeptr;
  HsBool result;
  void* arg1;
  nodeptr = C_GETARG1(1);
  IND_REMOVE(nodeptr);
  arg1 = (void*)derefForeignObj((ForeignObj*)GET_INT_VALUE(nodeptr));

  result = hs_isEOFBin(arg1);

  nodeptr = nhc_mkBool(result);
  INIT_PROFINFO(nodeptr,&pf_NHC_46Binary_46hs_95isEOFBin_35);
  C_RETURN(nodeptr);
}
